package com.muyu.cloud.pay.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.muyu.cloud.pay.domain.OrderPayCustomer;
import com.muyu.cloud.pay.domain.req.CustomerListReq;
import com.muyu.cloud.pay.mapper.OrderPayCustomerMapper;
import com.muyu.cloud.pay.service.OrderPayCustomerService;
import com.muyu.common.core.utils.StringUtils;
import lombok.extern.log4j.Log4j2;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * @Author: DongZeLiang
 * @date: 2024/7/30
 * @Description: 支付客户业务层实现类
 * @Version: 1.0
 */
@Log4j2
@Service
public class OrderPayCustomerServiceImpl
        extends ServiceImpl<OrderPayCustomerMapper, OrderPayCustomer>
        implements OrderPayCustomerService {


    /**
     * 查询客户集合
     *
     * @param customerListReq 请求参数
     *
     * @return 客户集合
     */
    @Override
    public List<OrderPayCustomer> selectList (CustomerListReq customerListReq) {
        LambdaQueryWrapper<OrderPayCustomer> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.like(
                StringUtils.isNotEmpty(customerListReq.getAppName()),
                OrderPayCustomer::getAppName, customerListReq.getAppName()
                );
        queryWrapper.like(
                StringUtils.isNotEmpty(customerListReq.getAppCode()),
                OrderPayCustomer::getAppCode, customerListReq.getAppCode()
        );
        queryWrapper.eq(
                StringUtils.isNotEmpty(customerListReq.getStatus()),
                OrderPayCustomer::getStatus, customerListReq.getStatus()
        );
        return this.list(queryWrapper);
    }
}
